@@ -31,7 +31,7 @@ BEGIN
     use APR::Request::Apache2;
     use Net::API::REST::Cookies;
     use URI;
-    use URI::Query;
+    use Net::API::REST::Query;
     use URI::Escape;
     use HTTP::AcceptLanguage;
     use Net::API::REST::DateTime;
@@ -688,7 +688,7 @@ sub query
 {
     my $self = shift( @_ );
     my $qs = $self->query_string;
-    my $qq = URI::Query->new( $qs );
+    my $qq = Net::API::REST::Query->new( $qs );
     my %hash = $qq->hash;
     return( \%hash );
 }
@@ -1066,61 +1066,6 @@ sub _try
     }
 }
 
-## URI::Query version 0.16 is not dealing with utf8 strings properly, so I am overwriting some part here to decode utf8
-package URI::Query;
-no warnings 'redefine'; 
-sub _parse_qs
-{
-    my $self = shift( @_ );
-    my $qs = shift( @_ );
-    for( split( /[&;]/, $qs ) )
-    {
-        my( $key, $value ) = map{ URI::Escape::uri_unescape( $_ ) } split( /=/, $_, 2 );
-        $key = Encode::decode_utf8( $key ) if( !Encode::is_utf8( $key ) );
-        $value = Encode::decode_utf8( $value ) if( !Encode::is_utf8( $value ) );
-        $self->{qq}->{$key} ||= [];
-        push( @{$self->{qq}->{$key}}, $value ) if( defined( $value ) && $value ne '' );
-    }
-    $self
-}
-
-sub _init_from_arrayref
-{
-    my( $self, $arrayref ) = @_;
-    while( @$arrayref )
-    {
-        my $key   = shift( @$arrayref );
-        my $value = shift( @$arrayref );
-        my $key_unesc = URI::Escape::uri_unescape( $key );
-        $key_unesc = Encode::decode_utf8( $key_unesc ) if( !Encode::is_utf8( $key_unesc ) );
-
-        $self->{qq}->{$key_unesc} ||= [];
-        if( defined( $value ) && $value ne '' )
-        {
-            my @values;
-            if( !ref( $value ) )
-            {
-                @values = split( "\0", $value );
-            }
-            elsif( ref( $value ) eq 'ARRAY' )
-            {
-                @values = @$value;
-            }
-            else
-            {
-                die( "Invalid value found: $value. Not string or arrayref!" );
-            }
-            # push @{$self->{qq}->{$key_unesc}}, map { uri_unescape($_) } @values;
-            for( @values )
-            {
-                $_ = URI::Escape::uri_unescape( $_ );
-                $_ = UTF::decode_utf8( $_ ) if( !Encode::is_utf8( $_ ) );
-                push( @{$self->{qq}->{$key_unesc}}, $_ );
-            }
-        }
-    }
-}
-
 1;
 
 __END__
@@ -1788,7 +1733,7 @@ See L<Apache::RequestUtil> for more information.
 
 =head2 query()
 
-Check the query string sent in the http request, which obviously should be a GET, but not necessarily, and parse it with L<URI::Query> and return a hash reference.
+Check the query string sent in the http request, which obviously should be a GET, but not necessarily, and parse it with L<Net::API::REST::Query> and return a hash reference.
 
 =head2 query_string( query string )
 
